@@ -4,7 +4,7 @@ use strict;
 #use warnings; bah -- not supported before 5.006
 
 use vars qw ($VERSION @EXPORT @ISA);
-$VERSION = "0.17";
+$VERSION = "0.18";
 
 # Required modules
 use Carp;
@@ -14,10 +14,6 @@ use Exporter;
 @ISA = qw( Exporter );
 @EXPORT = qw( delta_ok delta_within );
 
-#--------------------------------------------------------------------------#
-# main pod documentation #####
-#--------------------------------------------------------------------------#
-
 =head1 NAME
 
 Test::Number::Delta - Compare if the difference between two numbers 
@@ -199,16 +195,27 @@ sub delta_ok($$;$) {
 1; #this line is important and will help the module return a true value
 __END__
 
+=head1 SEE ALSO
+
+L<Test::More>, L<Test::Harness>, L<Test::Builder>
+
 =head1 BUGS
 
-Please report bugs using the CPAN Request Tracker at 
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=Test-Number-Delta
+Please report any bugs or feature using the CPAN Request Tracker.  
+Bugs can be submitted by email to C<bug-Test-Number-Delta@rt.cpan.org> or 
+through the web interface at 
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Test-Number-Delta>
+
+When submitting a bug or request, please include a test-file or a patch to an
+existing test-file that illustrates the bug or desired feature.
 
 =head1 AUTHOR
 
-David A Golden <dagolden@cpan.org>
+David A Golden (DAGOLDEN)
 
-http://dagolden.com/
+dagolden@cpan.org
+
+L<http://dagolden.com/>
 
 =head1 COPYRIGHT
 
@@ -220,9 +227,27 @@ it and/or modify it under the same terms as Perl itself.
 The full text of the license can be found in the
 LICENSE file included with this module.
 
+=head1 DISCLAIMER OF WARRANTY
 
-=head1 SEE ALSO
+BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
+FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
+OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
+PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
+EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
+ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
+YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
+NECESSARY SERVICING, REPAIR, OR CORRECTION.
 
-L<Test::More>, L<Test::Harness>, L<Test::Builder>
+IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
+REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
+LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
+OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
+THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
+RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
+FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
+SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
+SUCH DAMAGES.
 
 =cut
